@@ -1,5 +1,5 @@
 enc_in = {
-		"{LEFT}": "<",
+		"{RIGHT}": ">",
 		"{SPACE}": " ",
 		"{EQUAL}": "=",
 		"{NL}": "\n",
@@ -7,7 +7,7 @@ enc_in = {
 }
 
 enc_out = {
-	"<": "{LEFT}",
+	">": "{RIGHT}",
 	" ": "{SPACE}",
 	"=": "{EQUAL}",
 	"\n": "{NL}",
@@ -19,6 +19,7 @@ def create_node(node: dict):
 		name = node["name"]
 		attrs_ = node["attrs"]
 		attrs = ""
+		comments = ""
 
 		for attr in attrs_:
 			value = attrs_[attr]
@@ -28,7 +29,10 @@ def create_node(node: dict):
 
 			attrs += f" {attr}=\"{value}\""
 
-		child = node["value"]
+		for comment in node["comms"]:
+			comments += f"<!--{comment}-->"
+
+		child = ""
 
 		for enc_out_piece in enc_out:
 			child = child.replace(enc_out_piece, enc_out[enc_out_piece])
@@ -36,4 +40,6 @@ def create_node(node: dict):
 		for child_ in node["child"]:
 			child += create_node(child_)
 
-		return f"<{name}{attrs}>{child}</{name}>"
\ No newline at end of file
+		child += node["value"]
+
+		return f"<{name}{attrs}>{comments}{child}</{name}>"
\ No newline at end of file
