@@ -28,7 +28,7 @@ class xml(object):
 				start = self.__list
 
 			if line != "" and line != None:
-				if line[0] == "<" and line[1] != "/":
+				if line[0] == "<" and line[1] != "/" and line[1] != "!":
 					end = line.find(" ")
 
 					if end == -1 or end > line.find(">"):
@@ -37,7 +37,10 @@ class xml(object):
 					name = line[1:end]
 
 					if name != "":
-						attrs = line[end:line.find(">")]
+						if line.find(f"</{name}>") != -1:
+							attrs = line[end:line.find(">")]
+						else:
+							attrs = line[end:line.find("/>")]
 						attrs_ = attrs.split(" ")
 						attrs__ = {}
 
@@ -58,28 +61,52 @@ class xml(object):
 							"name": name,
 							"attrs": attrs__,
 							"child": [],
-							"value": ""
+							"value": "",
+							"comms": []
 						})
 
-						child = line[line.find(f"<{name}{attrs}>") + len(f"<{name}{attrs}>"):line.find(f"</{name}>")]
+						if line.find(f"</{name}>") != -1:
+							child = line[line.find(f"<{name}{attrs}>") + len(f"<{name}{attrs}>"):line.find(f"</{name}>")]
 
-						result = child
+							result = child
 
-						while True:
-							result = add_node(result, start[index]["child"], start[index])
+							while True:
+								result = add_node(result, start[index]["child"], start[index])
 
-							if result == "":
-								break
+								if result == "":
+									break
 
-						line = line.replace(f"<{name}{attrs}>{child}</{name}>", "")
+							return line.replace(f"<{name}{attrs}>{child}</{name}>", "")
+						else:
+							if f"<{name}{attrs}>"[-2] == "/":
+								return line.replace(f"<{name}{attrs}>", "")
+							else:
+								return line.replace(f"<{name}{attrs}/>", "")
+				elif line[0] == "<" and line[1] == "!":
+					comment = line[line.find("<!--") + len("<!--"):line.find("-->")]
 
-						return line
+					start_value["comms"].append(comment)
+
+					return line.replace(f"<!--{comment}-->", "")
 				else:
 					try:
 						for enc_in_piece in enc_in:
 							line = line.replace(enc_in_piece, enc_in[enc_in_piece])
 
-						start_value["value"] = line
+						end = line.find("<br/>")
+
+						if end == -1:
+							end = len(line)
+						else:
+							child = line[end + len("<br/>"):len(line)]
+							
+							while True:
+								child = add_node(child, start, start_value)
+
+								if child == "":
+									break
+
+						start_value["value"] = line[0:end] + start_value["value"]
 					except:
 						pass
 			else:
